<?php

namespace App\Http\Controllers\Admin;

use App\Models\Brand;
use App\Models\Product;
use App\Models\Category;
use App\Models\ProductImage;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\File;

class ProductController extends Controller
{
    public function index(Request $request)
    {

        $query = Product::query();
        // Search by product name or product code
        if ($request->filled('search')) {
            $query->where('name', 'like', '%' . $request->search . '%')
                ->orWhere('product_code', 'like', '%' . $request->search . '%');
        }

        // Filter by category
        if ($request->filled('category')) {
            $query->where('category_id', $request->category);
        }

        // Filter by brand
        if ($request->filled('brand')) {
            $query->where('brand_id', $request->brand);
        }

        $products = $query->with(['category', 'brand', 'images'])->paginate(10);

        $categories = Category::all();
        $brands = Brand::all();

        return view('Admin.product.index', compact('products', 'categories', 'brands'));
    }
    public function add()
    {
        $categories = Category::all();
        $brands = Brand::all();
        return view('Admin.product.add', compact('categories', 'brands'));
    }

    public function insert(Request $request)
    {
        $request->validate([
            'category_id' => 'required',
            'brand_id' => 'required',
            'name' => 'required|string|max:255',
            'product_code' => 'required|string|max:255',
            'description' => 'required|string',
            'in_stock' => 'required|integer',
            'old_price' => 'required',
            'sku' => 'required|string|max:255|unique:products', // Ensure SKU is unique
            'price' => 'required|numeric',
            'image' => 'required|array',
            'image.*' => 'image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        // Create the product
        $product = Product::create($request->only([
            'category_id',
            'brand_id',
            'name',
            'product_code',
            'description',
            'in_stock',
            'sku',
            'old_price',
            'price'
        ]));

        // Handle image uploads
        if ($request->hasFile('image')) {
            foreach ($request->file('image') as $file) {
                // Store images in 'public/product_images'
                $path = $file->store('images', 'public');
                // Create a new ProductImage record
                ProductImage::create([
                    'product_id' => $product->id,
                    'image' => $path, // Store the relative path
                ]);
            }
        }

        return redirect('/products')->with('status', "Product Added Successfully");
    }


    public function edit($id)
    {
        $product = Product::find($id);
        $categories = Category::all();
        $brands = Brand::all();
        return view('Admin.product.edit', compact('product', 'categories', 'brands'));
    }


    public function update(Request $request, $id)
    {
        // Validate the input data
        $request->validate([
            'category_id' => 'required',
            'brand_id' => 'required',
            'name' => 'required|string|max:255',
            'product_code' => 'required|string|max:255',
            'description' => 'required|string',
            'in_stock' => 'required|integer',
            'sku' => 'required|string|max:255|unique:products,sku,' . $id, // Ensure SKU is unique except for the current product
            'price' => 'required',
            'old_price' => 'required',
            'image' => 'nullable|array', // Image can be nullable during update
            'image.*' => 'image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        // Fetch the existing product
        $product = Product::findOrFail($id);

        // Update product details
        $product->update($request->only([
            'category_id',
            'brand_id',
            'name',
            'product_code',
            'description',
            'in_stock',
            'sku',
            'price',
            'old_price',
        ]));

        // Handle image uploads
        if ($request->hasFile('image')) {
            foreach ($request->file('image') as $file) {
                // Get the filename with extension
                $filename = $file->getClientOriginalName();

                // Store images in 'images' folder inside storage/app/public
                $file->storeAs('images', $filename, 'public');

                // Create a new ProductImage record
                ProductImage::create([
                    'product_id' => $product->id,
                    'image' => $filename, // Only save the filename in the database
                ]);
            }
        }

        return redirect('/products')->with('status', "Product Updated Successfully");
    }


    public function delete($id)
    {
        $product = Product::find($id);
        if ($product->image) {
            $path  = 'upload/product/' . $product->image;
            if (File::exists($path)) {
                File::delete($path);
            }
        }
        $product->delete();
        return redirect('/products')->with('status', "Product deleted Successfully");
    }
}
